# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, lib, flake-inputs, ... }:

{
  services.resolved.enable = false;

  networking.nameservers = [
    "172.16.1.53"
    "172.16.1.8"
  ];

  networking.defaultGateway = "172.16.1.1";

  virtualisation = {
    kvmgt.enable = true;
    containers = {
      enable = true;
      policy = {
        default = [ { type = "insecureAcceptAnything"; } ];
        transports = {
          docker-daemon = {
            "" = [ { type = "insecureAcceptAnything"; } ];
          };
        };
      };
    };
  };

  services.openssh.enable = true;
  networking.firewall.enable = false;

  environment.systemPackages = with pkgs; [
    neovim
    htop
    parted
    nfs-utils
    xfsprogs
  ];

  systemd.network.wait-online.enable = lib.mkDefault false;

  security.sudo = {
    enable = true;
    extraRules = [
      { users = [ "%wheel" ];
        commands = [ { command = "ALL"; options = [ "NOPASSWD" ]; } ];
      }
    ];
  };
}
